@@ -10,6 +10,8 @@ import time
 from logging_utils import create_log_file, FileLogger, update_logger, write_logger
 from erazhan_utils import get_time
 
+from time_utils import backto_Ntoday,trans_timestamp2str
+
 def test_logging_utils():
 
     app_version = "v122"
@@ -33,6 +35,16 @@ def test_logging_utils():
     text = "重新写入信息"
     write_logger(text, the_FH, info_type='info')
 
+def test_time_utilst():
+
+    int_time = int(time.time())
+    str_time = trans_timestamp2str(int_time,data_format = "%Y:%m:%d %H:%M:%S")
+    print("str_time:", str_time)
+
+    Nday = backto_Ntoday(N=1,data_format="%Y%m%d")
+    print("Nday:",Nday)
+
 if __name__ == "__main__":
-    test_logging_utils()
+    # test_logging_utils()
+    test_time_utilst()
     pass
\ No newline at end of file
